
/*
 * Copyright (c) 2006-2008 by Roland Riegel <feedback@roland-riegel.de>
 *
 * This file is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 */

#ifndef CLOCK_SYNC_H
#define CLOCK_SYNC_H

#include <stdbool.h>
#include <stdint.h>

/**
 * \addtogroup app
 *
 * @{
 */
/**
 * \addtogroup app_clock_sync
 *
 * @{
 */
/**
 * \file
 * TIME client header (license: GPLv2)
 *
 * \author Roland Riegel
 */

/**
 * The events generated by the clock synchronization.
 */
enum clock_sync_event
{
    /** An error occured during synchronization. */
    CLOCK_SYNC_EVT_ERROR = 0,
    /** A network timeout occured. */
    CLOCK_SYNC_EVT_TIMEOUT,
    /** The clock was successfully adjusted. */
    CLOCK_SYNC_EVT_SUCCESS
};

/**
 * The type of callback function used for issuing events.
 */
typedef void (*clock_sync_callback)(enum clock_sync_event evt);

bool clock_sync_start(clock_sync_callback callback);
void clock_sync_abort();

/**
 * @}
 * @}
 */

#endif

